/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:JLog.java 1465 2007-06-07 16:38:37Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.log;

import java.io.Serializable;

import org.ow2.util.i18n.I18n;

/**
 * Interface used for the logging.<br>
 * This don't use directly commons logging as the aim of this logging is to
 * provide internationalization abilities and to allow to use MessageFormat
 * message with an array of objects.
 * @author Florent Benoit
 */

public interface Log extends Serializable {

    /**
     * <p>
     * Is debug logging currently enabled?
     * </p>
     * <p>
     * Call this method to prevent having to perform expensive operations (for
     * example, <code>String</code> concatenation) when the log level is more
     * than debug.
     * </p>
     * @return true if it is enabled, else false
     */
    boolean isDebugEnabled();

    /**
     * <p>
     * Is error logging currently enabled?
     * </p>
     * <p>
     * Call this method to prevent having to perform expensive operations (for
     * example, <code>String</code> concatenation) when the log level is more
     * than error.
     * </p>
     * @return true if it is enabled, else false
     */
    boolean isErrorEnabled();

    /**
     * <p>
     * Is fatal logging currently enabled?
     * </p>
     * <p>
     * Call this method to prevent having to perform expensive operations (for
     * example, <code>String</code> concatenation) when the log level is more
     * than fatal.
     * </p>
     * @return true if it is enabled, else false
     */
    boolean isFatalEnabled();

    /**
     * <p>
     * Is info logging currently enabled?
     * </p>
     * <p>
     * Call this method to prevent having to perform expensive operations (for
     * example, <code>String</code> concatenation) when the log level is more
     * than info.
     * </p>
     * @return true if it is enabled, else false
     */
    boolean isInfoEnabled();

    /**
     * <p>
     * Is trace logging currently enabled?
     * </p>
     * <p>
     * Call this method to prevent having to perform expensive operations (for
     * example, <code>String</code> concatenation) when the log level is more
     * than trace.
     * </p>
     * @return true if it is enabled, else false
     */
    boolean isTraceEnabled();

    /**
     * <p>
     * Is warn logging currently enabled?
     * </p>
     * <p>
     * Call this method to prevent having to perform expensive operations (for
     * example, <code>String</code> concatenation) when the log level is more
     * than warn.
     * </p>
     * @return true if it is enabled, else false
     */
    boolean isWarnEnabled();

    /**
     * <p>
     * Log a message with trace log level.
     * </p>
     * @param message - This could be
     *        <ul>
     *        <li>an entry of an I18n repository</li>
     *        <li>a preformated message given to MessageFormat class</li>
     *        <li>or a simple object on which toString() method will be called</li>
     *        </ul>
     * @param args could be empty or contains the object for the formatter (I18n
     *        case). To log an exception, the exception must be the last
     *        argument.
     */
    void trace(final Object message, final Object... args);

    /**
     * <p>
     * Log a message with debug log level.
     * </p>
     * @param message - This could be
     *        <ul>
     *        <li>an entry of an I18n repository</li>
     *        <li>a preformated message given to MessageFormat class</li>
     *        <li>or a simple object on which toString() method will be called</li>
     *        </ul>
     * @param args could be empty or contains the object for the formatter (I18n
     *        case). To log an exception, the exception must be the last
     *        argument.
     */
    void debug(final Object message, final Object... args);

    /**
     * <p>
     * Log a message with info log level.
     * </p>
     * @param message - This could be
     *        <ul>
     *        <li>an entry of an I18n repository</li>
     *        <li>a preformated message given to MessageFormat class</li>
     *        <li>or a simple object on which toString() method will be called</li>
     *        </ul>
     * @param args could be empty or contains the object for the formatter (I18n
     *        case). To log an exception, the exception must be the last
     *        argument.
     */
    void info(final Object message, final Object... args);

    /**
     * <p>
     * Log a message with warn log level.
     * </p>
     * @param message - This could be
     *        <ul>
     *        <li>an entry of an I18n repository</li>
     *        <li>a preformated message given to MessageFormat class</li>
     *        <li>or a simple object on which toString() method will be called</li>
     *        </ul>
     * @param args could be empty or contains the object for the formatter (I18n
     *        case). To log an exception, the exception must be the last
     *        argument.
     */
    void warn(final Object message, final Object... args);

    /**
     * <p>
     * Log a message with error log level.
     * </p>
     * @param message - This could be
     *        <ul>
     *        <li>an entry of an I18n repository</li>
     *        <li>a preformated message given to MessageFormat class</li>
     *        <li>or a simple object on which toString() method will be called</li>
     *        </ul>
     * @param args could be empty or contains the object for the formatter (I18n
     *        case). To log an exception, the exception must be the last
     *        argument.
     */
    void error(final Object message, final Object... args);

    /**
     * <p>
     * Log a message with fatal log level.
     * </p>
     * @param message - This could be
     *        <ul>
     *        <li>an entry of an I18n repository</li>
     *        <li>a preformated message given to MessageFormat class</li>
     *        <li>or a simple object on which toString() method will be called</li>
     *        </ul>
     * @param args could be empty or contains the object for the formatter (I18n
     *        case). To log an exception, the exception must be the last
     *        argument.
     */
    void fatal(final Object message, final Object... args);


    /**
     * Gets the i18n object associated to this logger.
     * @return i18n object.
     */
    I18n getI18n();

}
